@@ -21,8 +21,10 @@ if os.name == "nt":
     USER_PICKLE = Path(os.getenv('LOCALAPPDATA')) / '.domains.user'
 
 else:
-    LOG_FILE = Path('/var/log/domains-api.log')
-    USER_PICKLE = Path('/usr/share/domains/.domains.user')
+    DIR = os.path.dirname(os.path.abspath(__file__))
+    LOG_FILE = Path(DIR) / 'domains-api.log'
+    USER_PICKLE = Path(DIR) / '.domains.user'
+    os.chdir(DIR)
 
 
 logger = logging.getLogger(__name__)
@@ -39,7 +41,7 @@ logger.addHandler(fh)
 
 def arg_parse(opts, instance):
 
-    """Parses command line options"""
+    """Parses command line options: e.g. "python -m domains_api --help" """
 
     for opt, arg in opts:
         if opt in {'-h', '--help'}:
@@ -54,9 +56,9 @@ def arg_parse(opts, instance):
     python -m domains_api -e --email         || -email set up wizard > use to delete email credentials (choose 'n')
     python -m domains_api -n --notifications || -toggle email notification settings > will not delete email address
     python -m domains_api -d --delete_user   || -delete current user profile
-    python -m domains_api -u user.file       || (or `--user_load path/to/user.file`) -load user from pickle file**
+    python -m domains_api -u user.file       || (or "--user_load path/to/user.file") -load user from pickle file**
                                              || **this will overwrite any current user profile without warning!
-                                             || **Backup "/.user" file to store multiple profiles.
+                                             || **Backup "./.domains.user" file to store multiple profiles.
 """
             )
         elif opt in {'-c', '--credentials'}:
@@ -68,7 +70,7 @@ def arg_parse(opts, instance):
             User.delete_user()
             logger.info('***User deleted***')
             print('>>>Run the script without options to create a new user, or '
-                  '`ipchecker.py -u path/to/pickle` to load one from file')
+                  '"python3 -m domains_api -u path/to/pickle" to load one from file')
         elif opt in {'-e', '--email'}:
             user = User()
             user.set_email()
@@ -139,7 +141,7 @@ class User:
                 self.notifications = 'Y'
             return self.notifications, self.gmail_address, self.gmail_password
         else:
-            return None, None
+            return 'n', None, None
 
     def send_notification(self, ip, msg_type='success', error=None):
 
